@@ -1,5 +1,5 @@
 #!/usr/bin/env python
 
 if __name__ == '__main__':
-    from airtest import cli
-    cli.main()
+    from airtest import console
+    console.main()
